@@ -13,7 +13,7 @@ use MIME::Base64      qw(decode_base64);
 use POSIX             qw(SEEK_END SEEK_SET);
 use XML::Entities     ();
 
-our $VERSION = '1.502';
+our $VERSION = '1.503';
 
 __PACKAGE__->_run( @ARGV ) unless caller;
 
@@ -50,7 +50,7 @@ that data structure and get back the plist as XML (but not binary
 yet). If you want to change the structure inbetween that's your
 business. :)
 
-See C<Mac::PropertyList> for more details.
+See L<Mac::PropertyList> for more details.
 
 =head2 Methods
 
@@ -87,8 +87,7 @@ Returns the C<Mac::PropertyList> data structure.
 
 sub plist            { $_[0]->{parsed}             }
 
-sub _object_size
-	{
+sub _object_size {
 	$_[0]->_trailer->{object_count} * $_[0]->_trailer->{offset_size}
 	}
 
@@ -127,8 +126,7 @@ sub _get_filehandle {
 	$fh;
 	}
 
-sub _read_plist_trailer
-	{
+sub _read_plist_trailer {
 	my $self = shift;
 
 	seek $self->_fh, -32, SEEK_END;
@@ -143,8 +141,7 @@ sub _read_plist_trailer
 	$self->{trailer} = \%hash;
 	}
 
-sub _get_offset_table
-	{
+sub _get_offset_table {
 	my $self = shift;
 
     seek $self->_fh, $self->_trailer->{table_offset}, SEEK_SET;
@@ -160,11 +157,9 @@ sub _get_offset_table
 
 	$self->{offsets} = \@offsets;
 
-    if( $self->_trailer->{offset_size} == 3 )
-    	{
+    if( $self->_trailer->{offset_size} == 3 ) {
 		@offsets = map { hex } @offsets;
    	 	}
-
 	}
 
 sub _read_object_at_offset {
@@ -190,11 +185,9 @@ my %singletons = (
     # implementation in CFBinaryPList.c but Apple's actual code has no
     # support for it at all, either reading or writing, so it's
     # probably not important to implement.
-
-);
+	);
 
 my $type_readers = {
-
 	0 => sub { # the odd balls
 		my( $self, $length ) = @_;
 
@@ -204,29 +197,42 @@ my $type_readers = {
     	},
 
 	1 => sub { # integers
-		my( $self, $length ) = @_;
-		croak "Integer > 8 bytes = $length" if $length > 3;
+		my( $self, $power2 ) = @_;
 
-		my $byte_length = 1 << $length;
+		croak "Integer with <$power2> bytes is not supported" if $power2 > 3;
+
+		my $byte_length = 1 << $power2;
 
 		my( $buffer, $value );
 		read $self->_fh, $buffer, $byte_length;
 
-		my @formats = qw( C n N NN );
-		my @values = unpack $formats[$length], $buffer;
+		my @formats = qw( C n N NN NNNN );
+		my @values = unpack $formats[$power2], $buffer;
 
-		if( $length == 3 )
-			{
+		if( $power2 == 3 ) {
 			my( $high, $low ) = @values;
 
 			my $b = Math::BigInt->new($high)->blsft(32)->bior($low);
-			if( $b->bcmp(Math::BigInt->new(2)->bpow(63)) > 0)
-				{
+			if( $b->bcmp(Math::BigInt->new(2)->bpow(63)) > 0) {
 				$b -= Math::BigInt->new(2)->bpow(64);
 				}
 
 			@values = ( $b );
 			}
+		elsif( $power2 == 4 ) {
+			my( $highest, $higher, $high, $low ) = @values;
+			my $b = Math::BigInt
+				->new($highest)
+				->blsft(32)->bior($higher)
+				->blsft(32)->bior($high)
+				->blsft(32)->bior($low);
+
+			if( $b->bcmp(Math::BigInt->new(2)->bpow(127)) > 0) {
+				$b -= Math::BigInt->new(2)->bpow(128);
+				}
+
+			@values = ( $b );
+			}
 
 		return Mac::PropertyList::integer->new( $values[0] );
 		},
@@ -358,25 +364,27 @@ my $type_readers = {
 		},
 	};
 
-sub _read_object
-	{
+sub _read_object {
 	my $self = shift;
-
+say "Reading object!";
     my $buffer;
+    say "\tTELL: ", tell( $self->_fh );
     croak "read() failed while trying to get type byte! $!"
     	unless read( $self->_fh, $buffer, 1) == 1;
 
     my $length = unpack( "C*", $buffer ) & 0x0F;
-
+say "\tlength is $length";
     $buffer    = unpack "H*", $buffer;
+    say "\t", join '', map { sprintf '%02x', ord } split //, $buffer;
     my $type   = substr $buffer, 0, 1;
+say "\ttype is $type";
 
 	$length = $self->_read_object->value if $type ne "0" && $length == 15;
 
 	my $sub = $type_readers->{ $type };
 	my $result = eval { $sub->( $self, $length ) };
 	croak "$@" if $@;
-
+say "RESULT: ", Dumper($result);
     return $result;
 	}
 
@@ -394,7 +402,7 @@ Some of the ideas are cribbed from CFBinaryPList.c
 
 This project is in Github:
 
-	git://github.com/briandfoy/mac-propertylist.git
+	https://github.com/briandfoy/mac-propertylist.git
 
 =head1 CREDITS
 
